@@ -161,7 +161,7 @@ class ContentExporter(UniqueObject, SimpleItem):
             if headfoot and headfoot != 'DEFAULT':
                 # Add html at end of xml
                 return output.replace('</properties>',
-                                      '''<html>![CDATA[\n%s]]</html>
+                                      '''<html><![CDATA[\n%s]]></html>
                                          \n</properties>''' % headfoot)
             else:
                 return output
